#!/usr/bin/env python
import sys,os

def configuration(parent_package='', top_path=None):
   from numpy.distutils.misc_util import Configuration

   # First, find what extra libs we need
   pglibs = None
   if "PGPLOT_DIR" not in os.environ:
      print "Please set your PGPLOT_DIR directory to point to the PGPLOT dir"
      sys.exit(1)
   if os.path.exists(os.path.join(os.environ['PGPLOT_DIR'],"makefile")):
      pgmake = open(os.path.join(os.environ['PGPLOT_DIR'], "makefile"))
      for line in pgmake:
         if line and line.split("=")[0] == "SHARED_LIB_LIBS":
            pglibs = line.split("=")[1]
            break
      pgmake.close()
   elif "PGPLOT_LIBS" not in os.environ:
      print "Sorry, I couldn't find the PGPLOT maekfile.  Please set an"
      print "environment variable PGPLOT_LIBS that has a space-separated"
      print "list of libraries and paths need for PGPLOT shared library"
      print "Example:"
      print "setenv PGPLOT_LIBS -L/usr/X11R6/lib -L/sw/lib -lX11 -lm -lpng"
      sys.exit(1)
   else:
      pglibs = os.environ['PGPLOT_LIBS']
      

   pglibs = pglibs.split()
   pglibdirs = []
   pglibraries = []
   for w in pglibs:
      if w[:2] == "-L":  pglibdirs.append(w[2:])
      elif w[:2] == "-l":  pglibraries.append(w[2:])
      else:  pglibraries.append(w)

   library_dirs = pglibdirs
   library_dirs.append(os.environ['PGPLOT_DIR'])
   for dir in ['PYTHONBASE','SCIDIR','SCISOFTDIR']:
      if dir in os.environ:
         library_dirs.append(os.environ[dir])

   config = Configuration('pygplot', parent_package, top_path)
   config.add_extension('cpgplot',
                       sources = ["cpgplot/cpgplot_wrap.c"],
                       include_dirs = ['./cpgplot'],
                       libraries = ['cpgplot','pgplot'] + pglibraries,
                       library_dirs = library_dirs)
   return config

if __name__ == '__main__':
   try:
      from numpy.distutils.core import setup
   except ImportError:
      print "Sorry, you need Numpy (Numerical Python) installed before you"
      print "can use pygplot.  Get it from http://numpy.scipy.org"
      sys.exit(1)

   setup(version="0.94",
      description="An Object Oriented wrapper around the PGPLOT Library",
      author="Chris Burns & Dan Kelson",
      url="http://www.ociw.edu/Code/python/burns-python-scripts/pygplot/",
      **configuration(top_path='').todict())

